summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qchecklistitem_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qchecklistitem_imp.h')
-rw-r--r--kjsembed/qtbindings/qchecklistitem_imp.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/kjsembed/qtbindings/qchecklistitem_imp.h b/kjsembed/qtbindings/qchecklistitem_imp.h
index 4ba46d32..a24c316f 100644
--- a/kjsembed/qtbindings/qchecklistitem_imp.h
+++ b/kjsembed/qtbindings/qchecklistitem_imp.h
@@ -10,7 +10,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
#include <kjsembed/jsbindingbase.h>
-class TQCheckListItem;
+class TTQCheckListItem;
/**
* Namespace containing the KJSEmbed library.
@@ -18,7 +18,7 @@ class TQCheckListItem;
namespace KJSEmbed {
namespace Bindings {
- class QCheckListItemLoader : public JSBindingBase
+ class TQCheckListItemLoader : public JSBindingBase
{
public:
KJS::Object createBinding(KJSEmbedPart *jspart, KJS::ExecState *exec, const KJS::List &args) const;
@@ -26,11 +26,11 @@ namespace Bindings {
};
}
/**
* Wrapper class for TQCheckListItem methods.
*
* @author Richard Moore, rich@kde.org
*/
-class QCheckListItemImp : public JSProxyImp
+class TQCheckListItemImp : public JSProxyImp
{
public:
/** Enumerates the constructors supported by this class. */
@@ -67,25 +67,25 @@ public:
Method_Last = -1
};
- QCheckListItemImp( KJS::ExecState *exec, int id, bool constructor=false );
- ~QCheckListItemImp();
+ TQCheckListItemImp( KJS::ExecState *exec, int id, bool constructor=false );
+ ~TQCheckListItemImp();
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TQCheckListItem *toQCheckListItem( KJS::Object &object );
+ static TTQCheckListItem *toTQCheckListItem( KJS::Object &object );
//
// Constructors implemented by this class.
//
- KJS::Object QCheckListItem_1( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QCheckListItem_2( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QCheckListItem_3( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QCheckListItem_4( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QCheckListItem_5( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QCheckListItem_6( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QCheckListItem_7( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QCheckListItem_8( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCheckListItem_1( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCheckListItem_2( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCheckListItem_3( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCheckListItem_4( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCheckListItem_5( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCheckListItem_6( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCheckListItem_7( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCheckListItem_8( KJS::ExecState *exec, const KJS::List &args );
//
// Methods implemented by this class.
@@ -123,7 +123,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TQCheckListItem *instance; // Temp
+ TTQCheckListItem *instance; // Temp
int id;
bool cons;
};
@@ -26,11 +26,11 @@ namespace Bindings {
}
/**
- * Wrapper class for TQCheckListItem methods.
+ * Wrapper class for TTQCheckListItem methods.
*
* @author Richard Moore, rich@kde.org